fileutil

package
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 18, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package fileutil provides file path utilities.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ReplaceExtension

func ReplaceExtension(filename, newExt string) string

ReplaceExtension replaces the file extension with a new one. If the filename has no extension, the new extension is appended.

Types

This section is empty.

Jump to