Documentation
¶
Overview ¶
Package schema provides embedded JSON Schema for PRISM types.
Index ¶
Constants ¶
const ( MaturityModelSchemaID = "https://github.com/grokify/prism-intelligence/schema/prism-maturity-model.schema.json" MaturityStateSchemaID = "https://github.com/grokify/prism-intelligence/schema/prism-maturity-state.schema.json" MaturityPlanSchemaID = "https://github.com/grokify/prism-intelligence/schema/prism-maturity-plan.schema.json" )
Schema IDs
Variables ¶
This section is empty.
Functions ¶
func MaturityModelSchemaJSON ¶
func MaturityModelSchemaJSON() []byte
MaturityModelSchemaJSON returns the raw JSON Schema bytes for Maturity Model.
func MaturityModelSchemaMap ¶
MaturityModelSchemaMap returns the Maturity Model schema as a map for programmatic access.
func MaturityPlanSchemaJSON ¶
func MaturityPlanSchemaJSON() []byte
MaturityPlanSchemaJSON returns the raw JSON Schema bytes for Maturity Plan.
func MaturityPlanSchemaMap ¶
MaturityPlanSchemaMap returns the Maturity Plan schema as a map for programmatic access.
func MaturityStateSchemaJSON ¶
func MaturityStateSchemaJSON() []byte
MaturityStateSchemaJSON returns the raw JSON Schema bytes for Maturity State.
func MaturityStateSchemaMap ¶
MaturityStateSchemaMap returns the Maturity State schema as a map for programmatic access.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.